@@ -1,9 +1,10 @@
-#!/opt/anaconda1anaconda2anaconda3\python.exe
+#!C:\conda\envs\_build\python.exe
 from __future__ import print_function
 
 import argparse
 import sys
 from compliance_checker.runner import ComplianceChecker, CheckSuite
+from compliance_checker.cf.util import download_cf_standard_name_table
 from compliance_checker import __version__
 
 
@@ -13,15 +14,14 @@ def main():
     check_suite.load_all_available_checkers()
 
     parser = argparse.ArgumentParser()
-    parser.add_argument('--test', '-t', '--test=', '-t=', default=('acdd',),
-                        nargs='+',
-                        choices=sorted(check_suite.checkers.keys()),
+    parser.add_argument('--test', '-t', '--test=', '-t=', default=[],
+                        action='append',
                         help="Select the Checks you want to perform.  Defaults to 'acdd' if unspecified")
 
     parser.add_argument('--criteria', '-c',
                         help="Define the criteria for the checks.  Either Strict, Normal, or Lenient.  Defaults to Normal.",
                         nargs='?', default='normal',
-                        choices = ['lenient', 'normal', 'strict'])
+                        choices=['lenient', 'normal', 'strict'])
 
     parser.add_argument('--verbose', '-v',
                         help="Increase output. May be specified up to three times.",
@@ -36,6 +36,8 @@ def main():
                         help='Display the IOOS Compliance Checker version information.')
     parser.add_argument('dataset_location', nargs='*',
                         help="Defines the location of the dataset to be checked.")
+    parser.add_argument('-l', '--list-tests', action='store_true', help='List the available tests')
+    parser.add_argument('-d', '--download-standard-names', help='Specify a version of the cf standard name table to download as packaged version')
 
     args = parser.parse_args()
 
@@ -43,13 +45,23 @@ def main():
         print("IOOS compliance checker version %s" % __version__)
         return 0
 
+    if args.list_tests:
+        print("IOOS compliance checker available checker suites (code version):")
+        for checker in sorted(check_suite.checkers.keys()):
+            version = getattr(check_suite.checkers[checker], '_cc_checker_version', "???")
+            print(" - {} ({})".format(checker, version))
+        return 0
+
+    if args.download_standard_names:
+        download_cf_standard_name_table(args.download_standard_names)
+
     return_values = []
     had_errors = []
     for dataset in args.dataset_location:
         if args.format != 'json':
             print("Running Compliance Checker on the dataset from: {}".format(dataset), file=sys.stderr)
         return_value, errors = ComplianceChecker.run_checker(args.dataset_location[0],
-                                                             args.test,
+                                                             args.test or ['acdd'],
                                                              args.verbose,
                                                              args.criteria,
                                                              args.output,
