@@ -1,10 +1,13 @@
 import itertools
+import requests
+import os
 from copy import deepcopy
 from collections import defaultdict
 from lxml import etree
 from cf_units import Unit
 from netCDF4 import Dimension, Variable
 from pkgutil import get_data
+from pkg_resources import resource_filename
 
 # copied from paegan
 # paegan may depend on these later
@@ -255,14 +258,23 @@ class StandardNameTable(object):
 
             return vals[0].text
 
-    def __init__(self, resource_name):
-        resource_text = get_data("compliance_checker", "data/cf-standard-name-table.xml")
+    def __init__(self, cached_location=None):
+        if cached_location:
+            try:
+                with open(cached_location, 'r') as fp:
+                    resource_text = fp.read()
+            except Exception:
+                resource_text = get_data("compliance_checker", "data/cf-standard-name-table.xml")
+        else:
+            resource_text = get_data("compliance_checker", "data/cf-standard-name-table.xml")
+
         parser = etree.XMLParser(remove_blank_text=True)
         self._root = etree.fromstring(resource_text, parser)
 
         # generate and save a list of all standard names in file
         self._names = [node.get('id') for node in self._root.iter('entry')]
         self._aliases = [node.get('id') for node in self._root.iter('alias')]
+        self._version = self._root.xpath('version_number')[0].text
 
     def __len__(self):
         return len(self._names) + len(self._aliases)
@@ -294,6 +306,40 @@ class StandardNameTable(object):
         return iter(itertools.chain(self._names, self._aliases))
 
 
+def download_cf_standard_name_table(version, location=None):
+    '''
+    Downloads the specified CF standard name table version and saves it to file
+
+    :param str version: CF standard name table version number (i.e 34)
+    :param str location: Path/filename to write downloaded xml file to
+    '''
+
+    if location is None:  # This case occurs when updating the packaged version from command line
+        location = resource_filename('compliance_checker', 'data/cf-standard-name-table.xml')
+
+    url = "http://cfconventions.org/Data/cf-standard-names/{0}/src/cf-standard-name-table.xml".format(version)
+    r = requests.get(url, allow_redirects=True)
+    if r.status_code == 200:
+        print("Downloading cf-standard-names table version {0} from: {1}".format(version, url))
+        with open(location, 'wb') as f:
+            f.write(r.content)
+    else:
+        r.raise_for_status()
+    return
+
+def create_cached_data_dir():
+    '''
+    Returns the path to the data directory to download CF standard names.
+    Use $XDG_DATA_HOME.
+    '''
+    writable_directory = os.path.join(os.path.expanduser('~'), '.local', 'share')
+    data_directory = os.path.join(os.environ.get("XDG_DATA_HOME", writable_directory),
+                                  'compliance-checker')
+    if not os.path.isdir(data_directory):
+        os.makedirs(data_directory)
+
+    return data_directory
+
 def units_known(units):
     try:
         Unit(units)
@@ -390,5 +436,3 @@ def is_vertical_coordinate(var_name, var):
     if not is_pressure:
         satisfied |= getattr(var, 'positive', '').lower() in ('up', 'down')
     return satisfied
-
-
