@@ -2,7 +2,7 @@
 
 from compliance_checker.suite import CheckSuite
 from compliance_checker.cf import CFBaseCheck, dimless_vertical_coordinates
-from compliance_checker.cf.util import is_vertical_coordinate, is_time_variable, units_convertible, units_temporal, NCGraph
+from compliance_checker.cf.util import is_vertical_coordinate, is_time_variable, units_convertible, units_temporal, StandardNameTable, create_cached_data_dir, download_cf_standard_name_table
 from netCDF4 import Dataset
 from tempfile import gettempdir
 from compliance_checker.tests.resources import STATIC_FILES
@@ -11,6 +11,7 @@ import unittest
 import os
 import re
 
+
 class MockVariable(object):
     '''
     For mocking a dataset variable
@@ -246,6 +247,22 @@ class TestCF(unittest.TestCase):
         for each in result:
             self.assertFalse(each.value)
 
+    def test_download_standard_name_table(self):
+        """
+        Test that a user can download a specific standard name table
+        """
+        version = '35'
+
+        data_directory = create_cached_data_dir()
+        location = os.path.join(data_directory, 'cf-standard-name-table-test-{0}.xml'.format(version))
+        download_cf_standard_name_table(version, location)
+
+        # Test that the file now exists in location and is the right version
+        self.assertTrue(os.path.isfile(location))
+        std_names = StandardNameTable(location)
+        self.assertEqual(std_names._version, version)
+        self.addCleanup(os.remove, location)
+
     def test_check_flags(self):
         dataset = self.load_dataset(STATIC_FILES['self_referencing'])
         results = self.cf.check_flags(dataset)
@@ -634,11 +651,6 @@ class TestCF(unittest.TestCase):
         self.assertFalse(results[0].value)
         self.assertTrue(results[1].value)
 
-    def test_check_alternative_coordinates(self):
-        dataset = self.load_dataset(STATIC_FILES['bad_data_type'])
-        results = self.cf.check_alternative_coordinates(dataset)
-        self.assertTrue(results[0].value)
-
     # def test_check_cell_boundaries(self):
     #    dataset = self.load_dataset(STATIC_FILES['bad_data_type'])
     #    results = self.cf.check_cell_boundaries(dataset)
